// filters.cc
// Contains definitions of record filtering and related functions
//
// Written by: Bienvenido Velez
// Copyright University of Puerto Rico - Mayaguez

// Standard C header files 
extern "C" {
#include <stdlib.h>
#include <string.h>
}

// Standard C++ include files
#include <iostream>

// My own header files
#include "utils.h"
#include "filters.h"

// Forward references to local auxiliary functions
static void setSessionFilter(int session);
static void setYearFilter(const char* year);
static void setCourseFilter(const char* course);
static void setSectionFilter(int section);

// Functions related to record filters
FilterCriteria selectFilterCriteria()
{
  int selection;
  do {
    cout << "Select filter criteria or exit:" << endl;
    cout << "    1) Filter by session"        << endl;
    cout << "    2) Filter by year"           << endl;
    cout << "    3) Filter by course"         << endl;
    cout << "    4) Filter by section"        << endl;
    cout << "    5) No Filtering"             << endl;
    cout << "    6) Exit"                     << endl;
    cout << "    Please enter your selection: ";
    cin >> selection;
  }
  while ((selection < 1) && (selection > 6));
  switch (selection) {
  case 1:  
    setSessionFilter(readInt("Enter session to filter (1 or 2): "));
    return Session;
  case 2:  
    setYearFilter(readString("Enter academic year to filter (e.g. 1991-1992): "));
    return Year;
  case 3:  
    setCourseFilter(readString("Enter course to filter (e.g. ICOM4015): "));
    return Course;
  case 4:  
    setSectionFilter(readInt("Enter section to filter (e.g. 111): "));
    return Section;
  case 5:  
    return NoFiltering;
  case 6:  return Exit;
  }
}

// Filtering by session
static int   sessionFilterValue;
void setSessionFilter(int session)
{
  sessionFilterValue = session;
}
bool sessionFilter(const DataRecord& r)
{
  return (r.session == sessionFilterValue);
}

// Filtering by year
static char* yearFilterValue;
void setYearFilter(const char *year)
{
  if (yearFilterValue != NULL) {
    delete [] yearFilterValue;
  }
  yearFilterValue = strdup(year);
}
bool yearFilter(const DataRecord& r)
{
  return (!strcmp(r.year, yearFilterValue));
}

// Filtering by course
static char* courseFilterValue;
void setCourseFilter(const char *course)
{
  if (courseFilterValue != NULL) {
    delete [] courseFilterValue;
  }
  courseFilterValue = strdup(course);
}
bool courseFilter(const DataRecord& r)
{
  return (!strcmp(r.course, courseFilterValue));
}

// Filtering by section
static int sectionFilterValue;
void setSectionFilter(int section)
{
  sectionFilterValue = section;
}
bool sectionFilter(const DataRecord& r)
{
  return (r.section == sectionFilterValue);
}

// No filtering
bool dummyFilter(const DataRecord& r)
{
  return true;
}

