// filters.h
// Header file
// Functions related to record filters
//
// Written by: Bienvenido Velez
// Copyright University of Puerto Rico - Mayaguez

// The following typedef defines a synonim for the type of function
// representing a record filter.  A record filtes is a boolean
// function that gets a data record and returns tru iff the record
// should be processed as part of the output. False if the record
// should be ignored.

#ifndef FILTERS_H
#define FILTERS_H

#include "DataRecord.h"

// Available filtering criteria
enum FilterCriteria {
  Session = 1,
  Year,
  Course,
  Section,
  NoFiltering,
  Exit
};

// Global declarations
static const int MAXCOURSE = 20;
static const int MAXYEAR   = 20;

// Selection of criteria
extern FilterCriteria selectFilterCriteria();

// Datatype representing filtering functions
typedef bool Filter(const DataRecord& r);

// Available filtering functions
extern bool sessionFilter (const DataRecord& r);
extern bool yearFilter    (const DataRecord& r);
extern bool courseFilter  (const DataRecord& r);
extern bool sectionFilter (const DataRecord& r);
extern bool dummyFilter   (const DataRecord& r);

#endif
