// report.cc
// Reporting module
// Contains all function pertaining to generating reports from the
// grades data file.
//
// Written by: Bienvenido Velez
// Copyright University of Puerto Rico - Mayaguez
//

#include <cstdlib>

// Standard C++ header files
#include <iostream>
#include <fstream>
#include <iomanip>

// My own header files
#include "filters.h"
#include "report.h"

void processRecords(istream& source, FilterCriteria filterBy)
{
  Filter* theFilter;
  switch (filterBy) {
  case Session:
    theFilter = sessionFilter;
    break;
  case Year:
    theFilter = yearFilter;
    break;
  case Course:
    theFilter = courseFilter;
    break;
  case Section:
    theFilter = sectionFilter;
    break;
  case NoFiltering:
    theFilter = dummyFilter;
    break;
  default:
    cerr << "Interna error in report.cc: illegal filtering criteria"
	 << endl;
    exit(1);
  }
  // Input variables, one per record field
  DataRecord nextRecord;
  nextRecord.year   = new char[MAXYEAR];
  nextRecord.course = new char[MAXCOURSE];

  // Statistical variables
  int numRecords = 0;
  int sumAs=0, sumBs=0, sumCs=0, sumDs=0, sumFs=0, sumWs=0, sumIs=0, sumTotal=0;
  printReportHeadings();

  while(true) {
    source >> nextRecord.session
	   >> nextRecord.year
	   >> nextRecord.course
	   >> nextRecord.section
	   >> nextRecord.numAs
	   >> nextRecord.numBs
	   >> nextRecord.numCs 
	   >> nextRecord.numDs 
	   >> nextRecord.numFs 
	   >> nextRecord.numWs 
	   >> nextRecord.numIs 
	   >> nextRecord.total;
    if (source.eof()) break;

    // Check if record satisfies filter
    if (!theFilter(nextRecord)) continue;

    // Add record to report if filter yields true
    printReportRecord(nextRecord);

    // Accumulate statistics

    // Add code here for part A

    // Keep counter of records
    numRecords++;
  }
  // Calculate statistics of grade frequency

  // Add code here for part A
  float avgAs = 0.0;
  float avgBs = 0.0;
  float avgCs = 0.0;
  float avgDs = 0.0;
  float avgFs = 0.0;
  float avgWs = 0.0;
  float avgIs = 0.0;
  float avgTs = 0.0;

  printReportFooter(avgAs, avgBs, avgCs, avgDs, avgFs, avgWs, avgIs, avgTs);

  delete [] nextRecord.year;
  delete [] nextRecord.course;
}


void printReportHeadings()
{
  // Add code here for part A
}


void printReportRecord(const DataRecord& r)
{
  // Add code here for part A
}

void printReportFooter(float avgAs, float avgBs, float avgCs, float avgDs,
		       float avgFs, float avgWs, float avgIs,
		       float avgTs)
{
  // Add code here for part A
}
